@@ -12,6 +12,10 @@
 #' @param sigma desired k x k covariance matrix between bivariate non-normal variables
 #'
 #' @author Phil Chalmers
+#' @references
+#' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
+#' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
+#' \url{http://www.tandfonline.com/doi/full/10.1080/10691898.2016.1246953}
 #' @export
 #' @examples
 #'
@@ -72,6 +76,9 @@ rmgh <- function(n, g, h, mean = rep(0, length(g)), sigma = diag(length(mean)))
 #' @param kurt a vector of k elements for the kurtosis of the variables
 #'
 #' @references
+#' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
+#' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
+#' \url{http://www.tandfonline.com/doi/full/10.1080/10691898.2016.1246953}
 #'
 #' Fleishman, A. I. (1978). A method for simulating non-normal distributions.
 #' \emph{Psychometrika, 43}, 521-532.
@@ -161,7 +168,7 @@ rValeMaurelli <- function(n, mean = rep(0, nrow(sigma)), sigma = diag(length(mea
 		p12
 	}
 	inter <- matrix(0, k, k)
-	for(i in 1L:k) {
+	for(i in seq_len(k)) {
 		for(j in i:k) {
 		    if(i == j) next
 			inter[i,j] <- solve.p12(cor[i,j],constants[i,1],constants[j,1],constants[i,2],constants[j,2],
@@ -206,6 +213,9 @@ rValeMaurelli <- function(n, mean = rep(0, nrow(sigma)), sigma = diag(length(mea
 #' @param control a list of control parameters when locating the polynomial coefficients
 #'
 #' @references
+#' Sigal, M. J., & Chalmers, R. P. (2016). Play it again: Teaching statistics with Monte
+#' Carlo simulation. \code{Journal of Statistics Education, 24}(3), 136-156.
+#' \url{http://www.tandfonline.com/doi/full/10.1080/10691898.2016.1246953}
 #'
 #' Headrick, T. C. (2002). Fast fifth-order polynomial transforms for generating univariate and
 #' multivariate nonnormal distributions. \emph{Computational Statistics & Data Analysis, 40}, 685-711.
